<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MircastShowWidget</name>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="57"/>
        <source>Exit Miracast</source>
        <translation>Miracast afsluiten</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="74"/>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation>Bezig met projecteren…
Sluit het programma niet af.</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="102"/>
        <source>Display device</source>
        <translation>Beeldapparaat</translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="67"/>
        <source>Project to</source>
        <translation>Projecteren naar</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="336"/>
        <source>Searching for devices...</source>
        <translation>Bezig met zoeken naar apparaten…</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="345"/>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation>Er zijn geen Miracast-apparaten aangetroffen. Zorg dat het apparaat en je computer verbonden zijn met hetzelfde wifi-netwerk.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="477"/>
        <location filename="../src/main.cpp" line="181"/>
        <location filename="../src/main.cpp" line="219"/>
        <location filename="../src/widgets/volumeslider.cpp" line="113"/>
        <location filename="../src/widgets/platform/platform_volumeslider.cpp" line="116"/>
        <location filename="../src/common/volumemonitoring.cpp" line="68"/>
        <location filename="../src/common/dmr_settings.cpp" line="192"/>
        <source>Movie</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="182"/>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation>Video&apos;s is een videospeler vol mogelijkheden die lokale video&apos;s en streams in allerlei formaten afspeelt.</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="186"/>
        <location filename="../src/common/settings_translation.cpp" line="59"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="189"/>
        <location filename="../src/common/settings_translation.cpp" line="57"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="194"/>
        <location filename="../src/common/settings_translation.cpp" line="58"/>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="10"/>
        <source>Auto add similar files to play</source>
        <translation>Voeg soortgelijke bestanden automatisch toe om af te spelen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="11"/>
        <source>Clear playlist when exit</source>
        <translation>Afspeellijst wissen na afsluiten</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="12"/>
        <source>Show thumbnails in progress bar</source>
        <translation>Miniaturen tonen op voortgangsbalk</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="13"/>
        <source>Show video preview on mouseover</source>
        <translation>Videovoorvertoning tonen bij overheen slepen van cursor</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="14"/>
        <source>Open a new player for each file played</source>
        <translation>Nieuw venster openen voor elk afgespeeld bestand</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="15"/>
        <source>Pause when minimized</source>
        <translation>Pauzeren bij minimaliseren</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="16"/>
        <source>Remember playback position</source>
        <translation>Afspeelpositie onthouden </translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="17"/>
        <source>Default play mode</source>
        <translation>Standaard afspeelmodus</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="18"/>
        <source>Path</source>
        <translation>Pad</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="19"/>
        <source>Basic</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="20"/>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="21"/>
        <location filename="../src/common/settings_translation.cpp" line="26"/>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="22"/>
        <source>Shortcuts</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="23"/>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="24"/>
        <source>Frame/Sound</source>
        <translation>Frame/Geluid</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="25"/>
        <source>Playback</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="27"/>
        <location filename="../src/common/settings_translation.cpp" line="28"/>
        <source>Subtitle</source>
        <translation>Ondertitel</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="29"/>
        <source>Font Style</source>
        <translation>Lettertypestijl</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="30"/>
        <source>Restore Defaults</source>
        <translation>Standaardwaarden herstellen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="31"/>
        <source>Open file</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="32"/>
        <source>Open next</source>
        <translation>Volgende openen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="33"/>
        <source>Open previous</source>
        <translation>Vorige openen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="34"/>
        <source>Mini mode</source>
        <translation>Mini-modus</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="35"/>
        <source>Mute</source>
        <translation>Dempen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="36"/>
        <source>Next frame</source>
        <translation>Volgend frame</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="37"/>
        <source>Previous frame</source>
        <translation>Vorig frame</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="38"/>
        <source>Volume down</source>
        <translation>Volume omlaag</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="39"/>
        <source>Volume up</source>
        <translation>Volume omhoog</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="40"/>
        <source>Speed up</source>
        <translation>Versnellen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="41"/>
        <source>Speed down</source>
        <translation>Vertragen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="42"/>
        <source>Fullscreen</source>
        <translation>Beeldvullende modus</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="43"/>
        <source>Pause/Play</source>
        <translation>Pauzeren/Afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="44"/>
        <source>Playlist</source>
        <translation>Afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="45"/>
        <source>Reset speed</source>
        <translation>Standaardsnelheid</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="46"/>
        <source>Delete from playlist</source>
        <translation>Verwijderen van afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="47"/>
        <source>Film info</source>
        <translation>Filminformatie</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="48"/>
        <source>Rewind</source>
        <translation>Terugspoelen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="49"/>
        <source>Forward</source>
        <translation>Vooruitspoelen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="50"/>
        <source>Burst shooting</source>
        <translation>Meerdere schermfoto&apos;s maken</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="51"/>
        <source>Film screenshot</source>
        <translation>Schermfoto van film</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="52"/>
        <source>0.5s backward</source>
        <translation>0.5s terugspoelen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="53"/>
        <source>0.5s forward</source>
        <translation>0.5s vooruitspoelen</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="54"/>
        <source>Font</source>
        <translation>Lettertype</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="55"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="56"/>
        <source>Exit fullscreen/mini mode</source>
        <translation>Beeldvullende of mini-modus verlaten</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="60"/>
        <source>Decoding</source>
        <translation>Decodering</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="61"/>
        <source>Auto select (Recommended)</source>
        <translation>Automatisch kiezen (aanbevolen)</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="62"/>
        <source>Hardware decoding</source>
        <translation>Hardwaredecodering</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="63"/>
        <source>Software decoding</source>
        <translation>Softwaredecodering</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="201"/>
        <location filename="../src/common/mainwindow.cpp" line="203"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Je bent niet gemachtigd om deze map te gebruiken</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="203"/>
        <location filename="../src/common/mainwindow.cpp" line="205"/>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="219"/>
        <location filename="../src/common/mainwindow.cpp" line="221"/>
        <source>Invalid folder</source>
        <translation>Ongeldige map</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="239"/>
        <location filename="../src/common/mainwindow.cpp" line="241"/>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2906"/>
        <location filename="../src/common/mainwindow.cpp" line="2875"/>
        <source>Network disconnected</source>
        <translation>Geen internetverbinding</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="17"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="18"/>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="22"/>
        <source>Please enter the URL:</source>
        <translation>Voer de url in:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../src/common/actions.cpp" line="53"/>
        <location filename="../src/common/actions.cpp" line="127"/>
        <location filename="../src/common/actions.cpp" line="314"/>
        <source>Open file</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="55"/>
        <location filename="../src/common/actions.cpp" line="128"/>
        <location filename="../src/common/actions.cpp" line="315"/>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="56"/>
        <location filename="../src/common/actions.cpp" line="310"/>
        <location filename="../src/common/actions.cpp" line="366"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="66"/>
        <location filename="../src/common/actions.cpp" line="138"/>
        <location filename="../src/common/actions.cpp" line="325"/>
        <source>Play Mode</source>
        <translation>Afspeelmodus</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="68"/>
        <location filename="../src/common/actions.cpp" line="140"/>
        <location filename="../src/common/actions.cpp" line="327"/>
        <source>Order Play</source>
        <translation>Afspeelvolgorde</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="69"/>
        <location filename="../src/common/actions.cpp" line="141"/>
        <location filename="../src/common/actions.cpp" line="328"/>
        <source>Shuffle Play</source>
        <translation>Willekeurig afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="70"/>
        <location filename="../src/common/actions.cpp" line="142"/>
        <location filename="../src/common/actions.cpp" line="329"/>
        <source>Single Play</source>
        <translation>Enkel afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="71"/>
        <location filename="../src/common/actions.cpp" line="143"/>
        <location filename="../src/common/actions.cpp" line="330"/>
        <source>Single Loop</source>
        <translation>Enkele herhaling</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="72"/>
        <location filename="../src/common/actions.cpp" line="144"/>
        <location filename="../src/common/actions.cpp" line="331"/>
        <source>List Loop</source>
        <translation>Lijst herhalen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="77"/>
        <location filename="../src/common/actions.cpp" line="164"/>
        <source>Frame</source>
        <translation>Frame</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="79"/>
        <location filename="../src/common/actions.cpp" line="166"/>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="86"/>
        <location filename="../src/common/actions.cpp" line="173"/>
        <source>Clockwise</source>
        <translation>Naar rechts</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="87"/>
        <location filename="../src/common/actions.cpp" line="174"/>
        <source>Counterclockwise</source>
        <translation>Naar links</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="89"/>
        <location filename="../src/common/actions.cpp" line="176"/>
        <source>Next Frame</source>
        <translation>Volgend frame</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="90"/>
        <location filename="../src/common/actions.cpp" line="177"/>
        <source>Previous Frame</source>
        <translation>Vorig frame</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="99"/>
        <location filename="../src/common/actions.cpp" line="149"/>
        <location filename="../src/common/actions.cpp" line="336"/>
        <source>Playback Speed</source>
        <translation>Afspeelsnelheid</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="101"/>
        <location filename="../src/common/actions.cpp" line="151"/>
        <location filename="../src/common/actions.cpp" line="338"/>
        <source>0.5x</source>
        <translation>0.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="102"/>
        <location filename="../src/common/actions.cpp" line="152"/>
        <location filename="../src/common/actions.cpp" line="339"/>
        <source>1.0x</source>
        <translation>1.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="103"/>
        <location filename="../src/common/actions.cpp" line="153"/>
        <location filename="../src/common/actions.cpp" line="340"/>
        <source>1.2x</source>
        <translation>1.2x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="104"/>
        <location filename="../src/common/actions.cpp" line="154"/>
        <location filename="../src/common/actions.cpp" line="341"/>
        <source>1.5x</source>
        <translation>1.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="105"/>
        <location filename="../src/common/actions.cpp" line="155"/>
        <location filename="../src/common/actions.cpp" line="342"/>
        <source>2.0x</source>
        <translation>2.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="129"/>
        <location filename="../src/common/actions.cpp" line="316"/>
        <source>Open URL</source>
        <translation>URL openen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="130"/>
        <location filename="../src/common/actions.cpp" line="317"/>
        <source>Open CD/DVD</source>
        <translation>CD/DVD openen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="132"/>
        <location filename="../src/common/actions.cpp" line="319"/>
        <source>Fullscreen</source>
        <translation>Beeldvullende modus</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="133"/>
        <location filename="../src/common/actions.cpp" line="320"/>
        <source>Mini Mode</source>
        <translation>Mini-modus</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="134"/>
        <location filename="../src/common/actions.cpp" line="321"/>
        <source>Always on Top</source>
        <translation>Altijd bovenaan</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="187"/>
        <source>Sound</source>
        <translation>Geluid</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="191"/>
        <source>Channel</source>
        <translation>Kanaal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="194"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="195"/>
        <source>Left channel</source>
        <translation>Linkerkanaal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="196"/>
        <source>Right channel</source>
        <translation>Rechterkanaal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="201"/>
        <location filename="../src/common/actions.cpp" line="424"/>
        <source>Track</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="214"/>
        <source>Subtitle</source>
        <translation>Ondertitel</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="216"/>
        <source>Load</source>
        <translation>Laden</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="217"/>
        <source>Online Search</source>
        <translation>Zoeken op internet</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="221"/>
        <source>Select</source>
        <translation>Kiezen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="225"/>
        <source>Hide</source>
        <translation>Verbergen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="228"/>
        <source>Encodings</source>
        <translation>Versleutelingen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="295"/>
        <location filename="../src/common/actions.cpp" line="352"/>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="298"/>
        <location filename="../src/common/actions.cpp" line="355"/>
        <source>Film Screenshot</source>
        <translation>Schermfoto van film</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="299"/>
        <source>Burst Shooting</source>
        <translation>Meerdere schermfoto&apos;s maken</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="300"/>
        <location filename="../src/common/actions.cpp" line="356"/>
        <source>Open screenshot folder</source>
        <translation>Schermfotomap openen</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="308"/>
        <location filename="../src/common/actions.cpp" line="364"/>
        <source>Playlist</source>
        <translation>Afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="309"/>
        <location filename="../src/common/actions.cpp" line="365"/>
        <source>Film Info</source>
        <translation>Filminformatie</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="375"/>
        <source>Delete from playlist</source>
        <translation>Verwijderen van afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="376"/>
        <source>Empty playlist</source>
        <translation>Lege afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="377"/>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="378"/>
        <source>Film info</source>
        <translation>Filminformatie</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="44"/>
        <source>Duration: %1</source>
        <translation>Duur: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="49"/>
        <source>Resolution: %1</source>
        <translation>Resolutie: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="54"/>
        <source>Size: %1</source>
        <translation>Grootte: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="77"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="852"/>
        <location filename="../src/common/mainwindow.cpp" line="2355"/>
        <location filename="../src/common/mainwindow.cpp" line="4225"/>
        <source>Load successfully</source>
        <translation>Laden voltooid</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="852"/>
        <location filename="../src/common/mainwindow.cpp" line="2355"/>
        <location filename="../src/common/mainwindow.cpp" line="2358"/>
        <location filename="../src/common/mainwindow.cpp" line="4225"/>
        <source>Load failed</source>
        <translation>Laden mislukt</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1695"/>
        <location filename="../src/common/mainwindow.cpp" line="2685"/>
        <source>Cannot play the disc</source>
        <translation>De schijf kan niet worden afgespeeld</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1712"/>
        <location filename="../src/common/mainwindow.cpp" line="3206"/>
        <source>Parse failed</source>
        <translation>Verwerken mislukt</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1720"/>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2092"/>
        <location filename="../src/common/mainwindow.cpp" line="2100"/>
        <location filename="../src/common/mainwindow.cpp" line="2108"/>
        <location filename="../src/common/mainwindow.cpp" line="2116"/>
        <location filename="../src/common/mainwindow.cpp" line="2124"/>
        <location filename="../src/common/mainwindow.cpp" line="2330"/>
        <location filename="../src/common/mainwindow.cpp" line="4409"/>
        <source>Speed: %1x</source>
        <translation>Snelheid: %1x</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2131"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2136"/>
        <source>Left channel</source>
        <translation>Linkerkanaal</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2141"/>
        <source>Right channel</source>
        <translation>Rechterkanaal</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2246"/>
        <source>Track: %1</source>
        <translation>Nummer: %1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2288"/>
        <location filename="../src/common/mainwindow.cpp" line="2305"/>
        <source>Unable to adjust the subtitle</source>
        <translation>De ondertiteling kan niet worden aangepast</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2293"/>
        <location filename="../src/common/mainwindow.cpp" line="2310"/>
        <source>Subtitle %1: %2s</source>
        <translation>Ondertitel %1: %2s</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2294"/>
        <location filename="../src/common/mainwindow.cpp" line="2311"/>
        <source>delayed</source>
        <translation>vertraagd</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2294"/>
        <location filename="../src/common/mainwindow.cpp" line="2311"/>
        <source>advanced</source>
        <translation>geavanceerd</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2452"/>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2461"/>
        <source>Film screenshot</source>
        <translation>Schermfoto van film</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2462"/>
        <source>Saved to</source>
        <translation>Opgeslagen in</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2483"/>
        <location filename="../src/common/mainwindow.cpp" line="2611"/>
        <source>The screenshot is saved</source>
        <translation>De schermfoto is opgelagen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2487"/>
        <location filename="../src/common/mainwindow.cpp" line="2615"/>
        <source>Failed to save the screenshot</source>
        <translation>De schermfoto kan niet worden opgeslagen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2571"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>Bezig met maken van schermfoto&apos;s...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2690"/>
        <source>Reading DVD files...</source>
        <translation>Bezig met uitlezen van dvd-bestanden...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4521"/>
        <source>Invalid file: %1</source>
        <translation>Ongeldig bestand: %1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4552"/>
        <source>Miracast disconnected</source>
        <translation>Miracast is ontkoppeld</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2882"/>
        <source>No matching online subtitles</source>
        <translation>Geen ondertiteling aangetroffen op internet</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1756"/>
        <location filename="../src/common/mainwindow.cpp" line="1793"/>
        <source>All (*)</source>
        <translation>Alles (*)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2898"/>
        <source>4K video may be stuck</source>
        <translation>4K-video kan haperen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2899"/>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2931"/>
        <location filename="../src/common/mainwindow.cpp" line="3855"/>
        <source>Order play</source>
        <translation>Afspeelvolgorde</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2934"/>
        <location filename="../src/common/mainwindow.cpp" line="3858"/>
        <source>Shuffle play</source>
        <translation>Willekeurig afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2937"/>
        <location filename="../src/common/mainwindow.cpp" line="3861"/>
        <source>Single play</source>
        <translation>Eén keer afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2940"/>
        <location filename="../src/common/mainwindow.cpp" line="3864"/>
        <source>Single loop</source>
        <translation>Eén keer herhalen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2943"/>
        <location filename="../src/common/mainwindow.cpp" line="3867"/>
        <source>List loop</source>
        <translation>Lijst herhalen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3097"/>
        <source>Buffering...</source>
        <translation>Bezig met bufferen...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3120"/>
        <location filename="../src/common/mainwindow.cpp" line="3145"/>
        <source>Mute</source>
        <translation>Dempen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3122"/>
        <location filename="../src/common/mainwindow.cpp" line="3147"/>
        <source>Volume: %1%</source>
        <translation>Volume: %1%</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3165"/>
        <location filename="../src/common/mainwindow.cpp" line="3197"/>
        <source>Cannot open file or stream</source>
        <translation>Bestand of stream kan niet worden geopend</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4510"/>
        <source>The action is not supported in this video</source>
        <translation>Deze actie wordt niet ondersteund door deze video</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4545"/>
        <source>Connection failed</source>
        <translation>Verbinding mislukt</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3214"/>
        <location filename="../src/common/mainwindow.cpp" line="3219"/>
        <source>Invalid file</source>
        <translation>Ongeldig bestand</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2339"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>Ondertitel (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3221"/>
        <source>Please insert a CD/DVD</source>
        <translation>Voer een cd of dvd in</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3226"/>
        <source>No video file found</source>
        <translation>Geen videobestand aangetroffen</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3846"/>
        <source>Please load the video first</source>
        <translation>Laad eerst de video</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3969"/>
        <location filename="../src/common/mainwindow.cpp" line="3977"/>
        <source>Please exit smart dock</source>
        <translation>Sluit het slimme dock af</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4270"/>
        <source>The CD/DVD has been ejected</source>
        <translation>De cd/dvd is uitgeworpen</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="243"/>
        <source>Film info</source>
        <translation>Filminformatie</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="295"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="296"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="297"/>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="302"/>
        <source>Path</source>
        <translation>Pad</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="307"/>
        <source>Codec info</source>
        <translation>Codecinformatie</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="328"/>
        <source>Video CodecID</source>
        <translation>Videocodec-id</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="329"/>
        <source>Video CodeRate</source>
        <translation>Video-coderate</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="275"/>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="288"/>
        <source>%1 kbps</source>
        <translation>%1 kbps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="276"/>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="289"/>
        <source>%1 bps</source>
        <translation>%1 bps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="330"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="278"/>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="331"/>
        <source>Proportion</source>
        <translation>Beeldverhouding</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="279"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="332"/>
        <source>Resolution</source>
        <translation>Resolutie</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="337"/>
        <source>Audio info</source>
        <translation>Audio-informatie</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="358"/>
        <source>Audio CodecID</source>
        <translation>Audiocodec-id</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="359"/>
        <source>Audio CodeRate</source>
        <translation>Audio-coderate</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="360"/>
        <source>Audio digit</source>
        <translation>Audiogetal</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="291"/>
        <source>%1 bits</source>
        <translation>%1 bits</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="361"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="292"/>
        <source>%1 channels</source>
        <translation>%1 kanalen</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="362"/>
        <source>Sampling</source>
        <translation>Sampling</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="293"/>
        <source>%1hz</source>
        <translation>%1hz</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="1744"/>
        <source>Internal</source>
        <translation>Intern</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="874"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2397"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4198"/>
        <source>Load successfully</source>
        <translation>Laden voltooid</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="874"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2397"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2400"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4198"/>
        <source>Load failed</source>
        <translation>Laden mislukt</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1755"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2736"/>
        <source>Cannot play the disc</source>
        <translation>De schijf kan niet worden afgespeeld</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1772"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3224"/>
        <source>Parse failed</source>
        <translation>Verwerken mislukt</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1780"/>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1808"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1837"/>
        <source>All (*)</source>
        <translation>Alles (*)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2134"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2142"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2150"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2158"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2166"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2372"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4382"/>
        <source>Speed: %1x</source>
        <translation>Snelheid: %1x</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2173"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2178"/>
        <source>Left channel</source>
        <translation>Linkerkanaal</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2183"/>
        <source>Right channel</source>
        <translation>Rechterkanaal</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2288"/>
        <source>Track: %1</source>
        <translation>Nummer: %1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2330"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2347"/>
        <source>Unable to adjust the subtitle</source>
        <translation>De ondertiteling kan niet worden aangepast</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2335"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2352"/>
        <source>Subtitle %1: %2s</source>
        <translation>Ondertitel %1: %2s</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2336"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2353"/>
        <source>delayed</source>
        <translation>vertraagd</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2336"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2353"/>
        <source>advanced</source>
        <translation>geavanceerd</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2381"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>Ondertitel (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2504"/>
        <source>View</source>
        <translation>Bekijk</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2513"/>
        <source>Film screenshot</source>
        <translation>Schermfoto van film</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2514"/>
        <source>Saved to</source>
        <translation>Opgeslagen in</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2535"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2662"/>
        <source>The screenshot is saved</source>
        <translation>De schermfoto is opgelagen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2539"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2666"/>
        <source>Failed to save the screenshot</source>
        <translation>De schermfoto kan niet worden opgeslagen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2623"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>Bezig met maken van schermfoto&apos;s...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2741"/>
        <source>Reading DVD files...</source>
        <translation>Bezig met uitlezen van dvd-bestanden...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2913"/>
        <source>No matching online subtitles</source>
        <translation>Geen ondertiteling aangetroffen op internet</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2929"/>
        <source>4K video may be stuck</source>
        <translation>4K-video kan haperen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2930"/>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2971"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3884"/>
        <source>Order play</source>
        <translation>Afspeelvolgorde</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2974"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3887"/>
        <source>Shuffle play</source>
        <translation>Willekeurig afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2977"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3890"/>
        <source>Single play</source>
        <translation>Eén keer afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2980"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3893"/>
        <source>Single loop</source>
        <translation>Eén keer herhalen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2983"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3896"/>
        <source>List loop</source>
        <translation>Lijst herhalen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3121"/>
        <source>Buffering...</source>
        <translation>Bezig met bufferen...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3144"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3169"/>
        <source>Mute</source>
        <translation>Dempen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3146"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3171"/>
        <source>Volume: %1%</source>
        <translation>Volume: %1%</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3215"/>
        <source>Cannot open file or stream</source>
        <translation>Bestand of stream kan niet worden geopend</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3232"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3237"/>
        <source>Invalid file</source>
        <translation>Ongeldig bestand</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3239"/>
        <source>Please insert a CD/DVD</source>
        <translation>Voer een cd of dvd in</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3244"/>
        <source>No video file found</source>
        <translation>Geen videobestand aangetroffen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3875"/>
        <source>Please load the video first</source>
        <translation>Laad eerst de video</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3995"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4002"/>
        <source>Please exit smart dock</source>
        <translation>Sluit het slimme dock af</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4243"/>
        <source>The CD/DVD has been ejected</source>
        <translation>De cd/dvd is uitgeworpen</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4483"/>
        <source>The action is not supported in this video</source>
        <translation>Deze actie wordt niet ondersteund door deze video</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4494"/>
        <source>Invalid file: %1</source>
        <translation>Ongeldig bestand: %1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4518"/>
        <source>Connection failed</source>
        <translation>Verbinding mislukt</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4525"/>
        <source>Miracast disconnected</source>
        <translation>Miracast is ontkoppeld</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="163"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="222"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="288"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="474"/>
        <source>The file does not exist</source>
        <translation>Dit bestand bestaat niet</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="646"/>
        <source>Playlist</source>
        <translation>Afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="672"/>
        <source>Empty</source>
        <translation>Legen</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="861"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1144"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1169"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1251"/>
        <source>%1 videos</source>
        <translation>%1 video&apos;s</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1143"/>
        <source>Play/Pause</source>
        <translation>Afspelen/Pauzeren</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1143"/>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1143"/>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1144"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1999"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2447"/>
        <source>Fullscreen</source>
        <translation>Beeldvullende modus</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1144"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2464"/>
        <source>Playlist</source>
        <translation>Afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1144"/>
        <source>Miracast</source>
        <translation>Miracast afsluiten</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1996"/>
        <source>Exit fullscreen</source>
        <translation>Beeldvullende modus verlaten</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2081"/>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2141"/>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="163"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="222"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="288"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="474"/>
        <source>The file does not exist</source>
        <translation>Dit bestand bestaat niet</translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="646"/>
        <source>Playlist</source>
        <translation>Afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="672"/>
        <source>Empty</source>
        <translation>Legen</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="861"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1144"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1169"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1251"/>
        <source>%1 videos</source>
        <translation>%1 video&apos;s</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="73"/>
        <source>Order play</source>
        <translation>Afspeelvolgorde</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="74"/>
        <source>Shuffle play</source>
        <translation>Willekeurig afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="75"/>
        <source>Single play</source>
        <translation>Eén keer afspelen</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="76"/>
        <source>Single loop</source>
        <translation>Eén keer herhalen</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="77"/>
        <source>List loop</source>
        <translation>Lijst herhalen</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="82"/>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="83"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="84"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="201"/>
        <source>%1/Movie%2(%3).jpg</source>
        <translation>%1/Film%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1216"/>
        <source>Play/Pause</source>
        <translation>Afspelen/Pauzeren</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1216"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2573"/>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1216"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2590"/>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1217"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2114"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2116"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2607"/>
        <source>Fullscreen</source>
        <translation>Beeldvullende modus</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1217"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2623"/>
        <source>Playlist</source>
        <translation>Afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1217"/>
        <source>Miracast</source>
        <translation>Miracast</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2108"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2110"/>
        <source>Exit fullscreen</source>
        <translation>Beeldvullende modus verlaten</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2204"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2206"/>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2269"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2271"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2558"/>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <location filename="../src/widgets/toolbutton.cpp" line="18"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
</context>
</TS>
